@@ -3,6 +3,7 @@ from arc.middleware import Middleware
 from arc.defaults import LoggingMiddleware, DefaultExceptionHandler
 from arc.staticfiles import StaticFile
 from arc.logger import Logger
+from starlette.websockets import WebSocket
 import uvicorn
 from parse import parse
 import traceback
@@ -105,16 +106,25 @@ class App:
 
         await self.middleware(scope, receive, send)
 
-    async def handle_request(self, request, websocket):
+    async def handle_request(self, request, type):
         try:
-            handler, kwargs, methods, type = self.find_handler(
+            handler, kwargs, methods = self.find_handler(
                 request_path=request.url.path)
 
-            if handler is None:
-                pass
             if type == "websocket":
-                pass
-            else:
+                if handler is not None:
+                    if inspect.iscoroutinefunction(handler):
+                        await handler(request, **kwargs)
+
+                    else:
+                        handler(request, **kwargs)
+
+                else:
+                    return self.default_response
+
+                return
+            
+            elif type == "http":
                 assert request.method.lower() in [method.lower(
                 ) for method in methods], f"Method {request.method.lower()} not allowed"
 
@@ -125,10 +135,7 @@ class App:
                         response = await handler(request, **kwargs)
 
                     else:
-                        if type == "route":
-                            response = handler(request, **kwargs)
-                        else:
-                            response = handler(websocket, **kwargs)
+                        response = handler(request, **kwargs)
                 else:
                     return self.default_response(request)
 
@@ -153,12 +160,11 @@ class App:
                 methods = items["methods"]
             except:
                 methods = None
-            type = items["type"]
             parse_result = parse(path, request_path)
             if parse_result is not None:
-                return handler, parse_result.named, methods, type
+                return handler, parse_result.named, methods
 
-        return None, None, methods, None
+        return None, None, methods
 
     def route(self, path: str, methods=["GET", "POST", "HEAD", "PUT", "DELETE", "CONNECT", "OPTIONS", "TRACE", "PATCH"]):
 
@@ -178,7 +184,7 @@ class App:
         assert path not in self.routes, f"Route {path} already exists"
 
         self.routes[path] = {"handler": handler,
-                             "methods": methods, "type": "route"}
+                             "methods": methods}
 
     def websocket(self, path: str):
         assert path not in self.routes, f"Route {path} already exists"
@@ -192,7 +198,7 @@ class App:
     def add_websocket(self, path, handler):
         assert path not in self.routes, f"Route {path} already exists"
 
-        self.routes[path] = {"handler": handler, "type": "websocket"}
+        self.routes[path] = {"handler": handler}
 
     def add_middleware(self, middleware_cls, *args):
         self.middleware.add(middleware_cls, *args)
