@@ -10,10 +10,23 @@ class Middleware:
 
     async def __call__(self, scope, receive, send):
         try:
-            request = Request(scope=scope, receive=receive)
-            websocket = WebSocket(scope=scope, receive=receive, send=send)
+            if scope["type"] == "http":
+                request = Request(scope=scope, receive=receive)
 
-            response = await self.app.handle_request(request, websocket)
+                response = await self.app.handle_request(request, "http")
+                
+
+            elif scope["type"] == "websocket":
+                websocket = WebSocket(scope=scope, receive=receive, send=send)
+
+                await self.app.handle_request(websocket, "websocket")
+                
+                await websocket.close()
+                
+                return
+            
+            elif scope["type"] == "lifespan":
+                return
 
             await response(scope, receive, send)
         except:
@@ -32,13 +45,13 @@ class Middleware:
     async def process_response(self, req, res):
         pass
 
-    async def handle_request(self, request):
+    async def handle_request(self, request, type):
         if inspect.iscoroutinefunction(self.process_request):
             await self.process_request(request)
         else:
             self.process_response(request)
 
-        response = await self.app.handle_request(request)
+        response = await self.app.handle_request(request, type)
 
         if inspect.iscoroutinefunction(self.process_response):
             await self.process_response(request, response)
